This is a system for retrieving java 8 document.
In order to use this system, you need to prepare 4 java doc files, namely JAVA_DOC.json, Java_Doc_Function_Similarity.json, Java_Doc_Similarity.csv and Java_Doc_Weights.csv, then place them under the java_doc path.
